use rocket::serde::{Deserialize, Serialize};

#[derive(Deserialize, Serialize)]
#[serde(crate = "rocket::serde")]
pub struct GamestateData {
    pub provider: Provider,
    pub auth: Auth,
    // pub map: Option<Map>,
    pub round: Option<Round>,
    pub player: Option<Player>,
}

#[derive(Deserialize, Serialize)]
#[serde(crate = "rocket::serde")]
pub struct Provider {
    pub name: String,
    pub appid: u16,
    pub version: u16,
    pub steamid: String,
    pub timestamp: u64,
}

#[derive(Deserialize, Serialize)]
#[serde(crate = "rocket::serde")]
pub struct Auth {
    pub token: String
}


#[derive(Deserialize, Serialize)]
#[serde(crate = "rocket::serde")]
pub struct Map {
    pub mode: String,
    pub name: String,
    pub phase: String,
    pub round: u16,
    pub team_ct: Team,
    pub team_t: Team,
    pub num_matches_to_win_series: u16,
    pub current_spectators: u16,
    pub souvenirs_total: u16,
}

#[derive(Deserialize, Serialize)]
#[serde(crate = "rocket::serde")]
pub struct Team {
    pub score: u16,
    pub consecutive_round_losses: u16,
    pub timeouts_remaining: u16,
    pub matches_won_this_series: u16,
}

#[derive(Deserialize, Serialize)]
#[serde(crate = "rocket::serde")]
pub struct Player {
    pub clan: Option<String>,
    pub spectarget: Option<String>,
    pub steamid: String,
    pub name: String,
    pub activity: String,
    // pub match_stats: MatchStats,
    pub state: Option<State>,
    // pub weapons: Weapons,
}

#[derive(Deserialize, Serialize)]
#[serde(crate = "rocket::serde")]
pub struct MatchStats {
    pub kills: u16,
    pub assists: u16,
    pub deaths: u16,
    pub mvps: u16,
    pub score: u16,
}

#[derive(Deserialize, Serialize)]
#[serde(crate = "rocket::serde")]
pub struct State {
    pub health: u16,
    pub armor: u16,
    pub helmet: bool,
    pub flashed: u16,
    pub smoked: u16,
    pub burning: u16,
    pub money: u16,
    pub round_kills: u16,
    pub round_killhs: u16,
    pub equip_value: u16,
}

#[derive(Deserialize, Serialize)]
#[serde(crate = "rocket::serde")]
pub struct Weapons {
    pub weapon_0: Weapon,
    pub weapon_1: Weapon,
}

#[derive(Deserialize, Serialize)]
#[serde(crate = "rocket::serde")]
pub struct Weapon {
    pub name: String,
    pub paintkit: String,
    pub type_: String,
    pub ammo_clip: u16,
    pub ammo_clip_max: u16,
    pub ammo_reserve: u16,
    pub state: String,
    // pub ammo_type: String,
    // pub stat_trak: u16,
    // pub weapon_type: String,
    // pub weapon_state: String,
}

#[derive(Deserialize, Serialize)]
#[serde(crate = "rocket::serde")]
pub struct Round {
    pub phase: String,
    pub bomb: Option<String>,
    // pub win_team: String,
    // pub bomb_planted: bool,
    // pub round_wins: RoundWins,
}

